@@ -1,5 +1,15 @@
 from six import string_types, binary_type
 
+import locale
+
+try:
+    locale.setlocale(locale.LC_ALL, '')
+    CHARSET = locale.getlocale(locale.LC_CTYPE)[1]
+except locale.Error:
+    CHARSET = None
+if CHARSET is None:
+    CHARSET = 'ascii'
+
 
 def is_iterable(obj):
     """ Method that verifies if an object is iterable and not a string, example:
@@ -17,11 +27,11 @@ def is_iterable(obj):
 
 def decode(string, errors='replace'):
     if isinstance(string, binary_type) and not isinstance(string, string_types):
-        return string.decode(encoding=base.CHARSET, errors=errors)
+        return string.decode(encoding=CHARSET, errors=errors)
     return string
 
 
 def encode(string, errors='replace'):
     if isinstance(string, string_types) and not isinstance(string, binary_type):
-        return string.encode(encoding=base.CHARSET, errors=errors)
+        return string.encode(encoding=CHARSET, errors=errors)
     return string
